@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20230320';
+our $VERSION = '5.20230420';
 our %utilities;
 
 sub utilities {
@@ -1881,6 +1881,13 @@ my %delta = (
         removed => {
         }
     },
+    5.037011 => {
+        delta_from => 5.03701,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
